added few type reinterpret cast device functions
1. __int_as_float 2. __hiloint2double Change-Id: Id247c196887b24a12090f0521bf91e13afeec733
This commit is contained in:
@@ -0,0 +1,58 @@
|
||||
/*
|
||||
Copyright (c) 2015-2016 Advanced Micro Devices, Inc. All rights reserved.
|
||||
Permission is hereby granted, free of charge, to any person obtaining a copy
|
||||
of this software and associated documentation files (the "Software"), to deal
|
||||
in the Software without restriction, including without limitation the rights
|
||||
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
|
||||
copies of the Software, and to permit persons to whom the Software is
|
||||
furnished to do so, subject to the following conditions:
|
||||
The above copyright notice and this permission notice shall be included in
|
||||
all copies or substantial portions of the Software.
|
||||
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
|
||||
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
|
||||
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
|
||||
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
|
||||
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
|
||||
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
|
||||
THE SOFTWARE.
|
||||
*/
|
||||
|
||||
#include <hip/device_functions.h>
|
||||
|
||||
extern "C" float __hip_int_as_float(int);
|
||||
|
||||
typedef struct {
|
||||
signed int hi;
|
||||
signed int lo;
|
||||
} __hip_signed_2;
|
||||
|
||||
typedef struct {
|
||||
union {
|
||||
double d;
|
||||
long long int lli;
|
||||
__hip_signed_2 s2;
|
||||
} ;
|
||||
} __hip_64bit_struct;
|
||||
|
||||
typedef struct {
|
||||
union {
|
||||
float f;
|
||||
unsigned int ui;
|
||||
signed int si;
|
||||
};
|
||||
} __hip_32bit_struct;
|
||||
|
||||
__device__ float __int_as_float (int x) {
|
||||
__hip_32bit_struct s;
|
||||
s.si = x;
|
||||
return s.f;
|
||||
}
|
||||
|
||||
__device__ double __hiloint2double (int hi, int lo) {
|
||||
__hip_64bit_struct s;
|
||||
s.s2.hi = hi;
|
||||
s.s2.lo = lo;
|
||||
return s.d;
|
||||
}
|
||||
|
||||
|
||||
مرجع در شماره جدید
Block a user